@@ -553,17 +553,20 @@ class DataTransform(forms.ModelForm):
 
     def __init__(self, *args, **kwargs):
         super(DataTransform, self).__init__(*args, **kwargs)
-        if hasattr(self.instance, 'get_children') and self.instance.get_children() > 0:
-            dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,
-                                                                 fk_name='parent', form=DataTransform,
-                                                                 extra=self.instance.get_children() + 1
-                                                                 )
-            self.nested_data_transformer_form = dataTransformerInlineFormset(
-                instance=self.instance,
-                data=self.data if self.is_bound else None,
-                files=self.files if self.is_bound else None,
-                initial=[{'parent': self.instance.id}]
-            )
+        try:
+            if hasattr(self.instance, 'get_children') and self.instance.get_children() > 0:
+                dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,
+                                                                     fk_name='parent', form=DataTransform,
+                                                                     extra=self.instance.get_children() + 1
+                                                                     )
+                self.nested_data_transformer_form = dataTransformerInlineFormset(
+                    instance=self.instance,
+                    data=self.data if self.is_bound else None,
+                    files=self.files if self.is_bound else None,
+                    initial=[{'parent': self.instance.id}]
+                )
+        except Exception:
+            print('excpt')
 
         self.instance.get_children().count() + 1
 
